global_settings{
  assumed_gamma 1.0
  #if (use_rad)
  radiosity{ 
    pretrace_start 0.08 pretrace_end 0.01 count 80*1
    nearest_count 10
    error_bound .5
    recursion_limit 1
    brightness 1
    always_sample off
    normal off
    media off
  }
  #end
}
#default{texture{finish{ambient 0 diffuse 1}}}
#include "colors.inc"
#include "textures.inc"
#include "stones.inc"
#include "glass.inc"
#include "functions.inc"
#include "transforms.inc"


// ******
// CAMERA
// ******
camera{ 
  location <2,15,-40>
  up 2.4*y right 3.2*x
  direction 8.5*z
  look_at <-1,5,-9>
  #if (use_blur>0)
    aperture .67 blur_samples 7*use_blur focal_point <-1,5,-9>
  #end
}


// ***********
// OUTDOOR HDR
// ***********
sphere{0,10e5
 pigment{image_map{hdr "pd_campus_probe_1" map_type 1 interpolate 2}} // cannot redistribute this file, sorry...
 finish{emission .5 diffuse 0}
 no_shadow
 hollow
 rotate -90*y
}


// ***********
// GRASS FIELD
// ***********
#if (use_grass)
#declare t_yerba = texture{
  pigment{
    uv_mapping
    image_map{jpeg "banana_leaves_detail_234987234.JPG" interpolate 2}
    translate -.5*x
    scale 10
	}
  finish{reflection{0,.1}}
  #if(use_normals)
  normal{granite .1 scale .01}
  #end
}
#declare grassfield_width=60;
#declare f_distrib=
function{
  pigment{
    granite scale grassfield_width*.5
  }
}
#declare num_sections=8*5;
#include "i_grass.inc"
#declare r_grass=seed(813);
#declare num_grass_patches=400;
#declare grass_patches_count=0;
#declare yerba=
union{
#while (grass_patches_count<num_grass_patches)
 #declare grass_patch_location=<-grassfield_width*.5+grassfield_width*rand(r_grass),0,-grassfield_width*.5+grassfield_width*rand(r_grass)>;
 #if (f_distrib(grass_patch_location.x,0,grass_patch_location.z).gray>.2)
 mesh{
  grass(rand(r_grass))
  rotate 360*rand(r_grass)*y
  translate grass_patch_location
 }
 #declare grass_patches_count=grass_patches_count+1;
 #end
#end
double_illuminate
}
object{yerba
 texture{t_yerba}
}
#end


// **********
// RAIN DROPS
// **********
#if (use_drops)
#declare r_drops=seed(490);
#declare num_drops=30000;
#declare drops_count=0;
blob{threshold .5
#while (drops_count<num_drops)
  #declare grass_patch_location=<-grassfield_width*.5+grassfield_width*rand(r_drops),1000,-grassfield_width*.5+grassfield_width*rand(r_drops)>;
  #declare Norm=<0,0,0>;
  #declare drop_rad=(.3+.7*rand(r_drops))*.2;
  #declare Inter=trace(yerba,grass_patch_location,-y,Norm);
  #if (Norm.gray!=0 & Norm.y>.3)
    #declare Norm1=<0,0,0>;
    #declare Norm2=<0,0,0>;
    #declare Norm3=<0,0,0>;
    #declare Norm4=<0,0,0>;
    #declare start1=<Inter.x-drop_rad,1000,Inter.z-drop_rad>;
    #declare start2=<Inter.x-drop_rad,1000,Inter.z+drop_rad>;
    #declare start3=<Inter.x+drop_rad,1000,Inter.z-drop_rad>;
    #declare start4=<Inter.x+drop_rad,1000,Inter.z+drop_rad>;
    #declare Inter1=trace(yerba,start1,-y,Norm1);
    #declare Inter2=trace(yerba,start2,-y,Norm2);
    #declare Inter3=trace(yerba,start3,-y,Norm3);
    #declare Inter4=trace(yerba,start4,-y,Norm4);
    #if ((Norm1.gray!=0) & (Norm2.gray!=0) & (Norm3.gray!=0) & (Norm4.gray!=0))
     #if (abs(Inter.y-((Inter1.y+Inter2.y+Inter3.y+Inter4.y))/4)<.2)
        sphere{0,1,1
          scale drop_rad
          scale <1,.5,1>
          scale <.8+.2*rand(r_drops),1,1>
          Reorient_Trans(y,Norm)
          translate Inter
        }
        sphere{0,1,-1
          scale drop_rad*1.6
          translate -drop_rad*y
          scale <1,.5,1>
          scale <.8+.2*rand(r_drops),1,1>
          Reorient_Trans(y,Norm)
          translate Inter
        }
      #declare drops_count=drops_count+1;
     #end
    #end
  #end
#end
  material{
    texture{
      T_Glass1
      finish{ambient 0 reflection{.1,.9}}
    }
    interior{I_Glass1 ior 1.33 caustics 10}
  }
}
#end


// *******
// TERRAIN
// *******
#declare t_tierra = texture{
	 pigment{
    image_map{jpeg "mayang_soil_1" interpolate 2}
   }
   normal{
    bump_map{jpeg "mayang_soil_1" bump_size 1 interpolate 2}
   }
   translate -.5
   rotate 90*x
   scale 50 
}
height_field{
 function 512,512{f_granite(x*2,y*2,z*2)}
 translate -.5
 scale <grassfield_width*1.5,2,grassfield_width*1.5>
 texture{t_tierra}
}

